# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.generalFilePermissions

Module implementing a check for setting too permissive file permissions.

### Global Attributes

None

### Classes

None

### Functions

checkFilePermissions | Function to check for setting too permissive file permissions.
getChecks | Public method to get a dictionary with checks handled by this module.

## checkFilePermissions

checkFilePermissions(reportError, context, config)

Function to check for setting too permissive file permissions.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up